%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%define lib_major 3
%define lib_api 1
%define lib_name %mklibname dbus- %{lib_api} %{lib_major}
%define develname %mklibname -d dbus- %lib_api

%define enable_test 0
%define enable_verbose 0

%define _with_systemd 0

%define git_url git://git.freedesktop.org/git/dbus/dbus

Summary: D-Bus message bus
Summary(de): D-Bus Nachrichten Bus
Name: dbus
Version: 1.14.10
Release: %mkrel 1
URL: http://www.freedesktop.org/Software/dbus
Source0: http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.xz
Source1: doxygen_to_devhelp.xsl
Source2: messagebus
#Patch0:   dbus-initscript.patch
Patch1:	  dbus-1.0.2-disable_fatal_warning_on_check.patch
License: GPLv2+ or AFL
Group: System/Servers
%if !%bootstrap
BuildRequires: xmlto docbook-dtd412-xml
BuildRequires: doxygen
%endif
BuildRequires: autoconf-archive
BuildRequires: lib64audit-devel
BuildRequires: lib64dbus-glib-1_2-devel
BuildRequires: lib64expat1-devel
BuildRequires: lib64glib2.0-devel
BuildRequires: lib64x11-devel
BuildRequires: libxml2-utils
BuildRequires: libtool
BuildRequires: make
BuildRequires: mktemp
BuildRequires: x11-proto-devel
BuildRequires: xmlto
BuildRequires: xsltproc
%if %{_with_systemd}
BuildRequires: pkgconfig(systemd)
%endif
Requires(pre): rpm-helper
Requires(preun): rpm-helper
Requires(post): rpm-helper
Requires(postun): rpm-helper
Requires(post): chkconfig
Requires(post): %{lib_name} >= %{version}-%{release}
Provides: should-restart = system
BuildRoot: %_tmppath/%name-%version-%release-root

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.
#german
%description -l de
D-Bus ist zuständig für das Senden von Nachrichten zwischen den 
Anwendungen. Es ist für den anlagenweiten Bus-Service verantwortlich, 
als auch für Pro-User-Login-Session-Messaging-Anlage.

%package -n %{lib_name}
Summary: Shared library for using D-Bus
Summary(de): Gemeinsame Bibliothek zum nutzen von D-Bus
Group: System/Libraries
Requires: dbus >= %{version}

%description -n %{lib_name}
D-Bus shared library.
#german
%description -n %{lib_name} -l de
%{summary}.

%package -n %develname
Summary: Libraries and headers for D-Bus
Summary(de): Entwicklerdateien für D-Bus
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: %{lib_name} = %{version}
Provides: lib%{name}-1-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Conflicts: lib64dbus-1_0-devel
Obsoletes: %mklibname -d dbus- 1 3

%description -n %develname
Headers and static libraries for D-Bus.
#german
%description -n %develname -l de
Headerdateien und statische Bibliotheken für D-Bus.

%package x11
Summary: X11-requiring add-ons for D-Bus
Summary(de): X11-relevante Addons für D-Bus
Group: System/Servers
Requires: dbus = %{version}

%package doc
Summary: Developer documentation for D-BUS
Summary(de): Entwickler Handbuch für D-Bus
Group: Documentation
Requires: dbus = %{version}
Conflicts: %develname < 1.2.20

%description doc 
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.
#german
%description doc -l de
%{summary}.

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.
#german
%description x11 -l de
D-Bus enthält einige Tools und wird benötigt für Xlib. In diesem Paket 
sind separate Server-Systeme, die nicht installiert sein müssen.

%prep
%setup -q
%autopatch -p1


%build

./autogen.sh

%define _localstatedir %{_var}

COMMON_ARGS="--disable-static --disable-selinux --with-system-pid-file=%{_var}/run/messagebus.pid --with-system-socket=%{_var}/run/dbus/system_bus_socket --with-session-socket-dir=/tmp --libexecdir=/%{_lib}/dbus-%{lib_api}" 

#### Build once with tests to make check
%if %{enable_test}
%configure2_5x $COMMON_ARGS --enable-tests=yes \
               --enable-verbose-mode=yes \
               --enable-asserts=yes \
               --disable-doxygen-docs \
               --enable-userdb-cache \
%if !%{_with_systemd}
               --without-systemdsystemunitdir \
%endif
               --disable-xml-docs
DBUS_VERBOSE=1 %make
make check

#### Clean up and build again 
make clean
%endif 

%configure2_5x $COMMON_ARGS --disable-tests --disable-asserts \
%if !%bootstrap
 --enable-doxygen-docs --enable-xml-docs \
%endif
%if %enable_verbose
 --enable-verbose-mode=yes
%else 
 --enable-verbose-mode=no
%endif
%make

%if !%bootstrap
doxygen Doxyfile

xsltproc -o dbus.devhelp %{SOURCE1} doc/api/xml/index.xml
%endif


%install
rm -rf %{buildroot}

%makeinstall_std

# move lib to /, because it might be needed by hotplug script, before
# /usr is mounted
mkdir -p %{buildroot}/%{_lib} %buildroot%{_var}/lib/dbus
mv %{buildroot}%{_libdir}/*dbus-1*.so.* %{buildroot}/%{_lib} 
ln -sf ../../%{_lib}/libdbus-%{lib_api}.so.%{lib_major} %{buildroot}%{_libdir}/libdbus-%{lib_api}.so

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit.d
cat << EOF > %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus
#!/bin/bash
# to be sourced
if [ -z "\$DBUS_SESSION_BUS_ADDRESS" ]; then
  eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
fi
EOF
chmod 755 %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir %{buildroot}%{_datadir}/dbus-%{lib_api}/interfaces

%if %{_with_systemd}
# Make sure that when somebody asks for D-Bus under the name of the
# old SysV script, that he ends up with the standard dbus.service name
# now.
ln -s dbus.service %{buildroot}/lib/systemd/system/messagebus.service
%endif

#add devhelp compatible helps
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus/api

%if !%bootstrap
cp dbus.devhelp %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-specification.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-faq.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-tutorial.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/api/html/* %{buildroot}%{_datadir}/devhelp/books/dbus/api
%endif


#remove unpackaged file
find %{buildroot} -name '*.la' | xargs rm

mkdir -p %{buildroot}/%{_sysconfdir}/rc.d/init.d
install -m 0755 %SOURCE2 %{buildroot}/%{_sysconfdir}/rc.d/init.d/messagebus


%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}-%{version}

%pre
rm -f /etc/rc.d/init.d/messagebus
%_pre_useradd messagebus / /sbin/nologin
%_pre_groupadd daemon messagebus

%post
if [ "$1" = "1" ]; then 
   /usr/bin/dbus-uuidgen --ensure
  /sbin/chkconfig --add messagebus  || /bin/true
fi

%postun
%_postun_userdel messagebus
%_postun_groupdel daemon messagebus

%preun
%_preun_service messagebus

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/dbus-%{lib_api}
%config(noreplace) %{_sysconfdir}/dbus-%{lib_api}/*.conf
%{_sysconfdir}/rc.d/init.d/*
%{_datadir}/xml/dbus-1/*.dtd
%dir %{_var}/run/dbus
%dir %{_var}/lib/dbus
%dir %{_libdir}/dbus-1.0
%{_bindir}/dbus-run-session
%{_bindir}/dbus-daemon
%{_bindir}/dbus-send
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{lib_api}
%{_datadir}/dbus-%{lib_api}/system-services
%{_datadir}/dbus-%{lib_api}/services
%{_datadir}/dbus-%{lib_api}/interfaces

%{_bindir}/dbus-test-tool
%{_bindir}/dbus-update-activation-environment

%{_datadir}/dbus-%{lib_api}/session.conf
%{_datadir}/dbus-%{lib_api}/system.conf

%{_datadir}/xml/dbus-1/catalog.xml

%dir /%{_lib}/dbus-%{lib_api}
%attr(4750,root,messagebus) /%{_lib}/dbus-%{lib_api}/dbus-daemon-launch-helper
%if %{_with_systemd}
/lib/systemd/system/dbus.service
/lib/systemd/system/messagebus.service
/lib/systemd/system/dbus.socket
/lib/systemd/system/dbus.target.wants/dbus.socket
/lib/systemd/system/multi-user.target.wants/dbus.service
/lib/systemd/system/sockets.target.wants/dbus.socket
%endif

%files -n %{lib_name}
%defattr(-,root,root)
/%{_lib}/*dbus-%{lib_api}*.so.%{lib_major}*

%files -n %develname
%defattr(-,root,root)
%{_libdir}/libdbus-%{lib_api}.so
%{_libdir}/dbus-1.0/include
%{_libdir}/pkgconfig/dbus-%{lib_api}.pc
%{_includedir}/dbus-1.0
%{_libdir}/cmake/DBus1/*.cmake

%files x11
%defattr(-,root,root)
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor

%files doc
%defattr(-,root,root)
%doc doc/introspect.dtd doc/introspect.xsl doc/system-activation.txt
%doc %{_datadir}/devhelp/books/dbus
%{_datadir}/doc


%changelog
* Sat Sep 02 2023 tex - 1.14.10-1pclos2023
- new version

* Fri Jun 30 2023 tex - 1.14.8-1pclos2023
- new version

* Sun Feb 12 2023 tex - 1.14.6-1pclos2023
- new version

* Fri Oct 07 2022 tex - 1.14.4-1pclos2022
- new version

* Tue Sep 27 2022 tex - 1.14.2-1pclos2022
- new version

* Wed Mar 02 2022 tex - 1.14.0-1pclos2022
- new version

* Sat Feb 26 2022 tex - 1.13.22-1pclos2022
- new version

* Fri Dec 24 2021 tex - 1.13.20-1pclos2022
- new version

* Sun Jun 27 2021 tex - 1.13.18-2pclos2021
- use bin/bash for messagebus script

* Sun Jun 06 2021 tex - 1.13.18-1pclos2021
- new version

* Thu Feb 21 2019 tex - 1.10.26-2pclos2019
- rebuild against updates

* Wed Feb 20 2019 tex - 1.10.26-1pclos2019
- NEW

* Tue Feb 13 2018 bb2 <bb2> - 1.10.6-2pclos2018
- rebuild against updates

* Sun Jan 17 2016 bb <bb> 1.10.6-1pclos2016
- update

* Tue Oct 13 2015 bb <bb> 1.8.20-1pclos2015
- update

* Mon Nov 10 2014 bb <bb> 1.8.10-1pclos2014
- update

* Sat Aug 30 2014 bb <bb> 1.6.22-2pclos2014
- add disable warnings patch
- add initscript patch

* Thu Aug 27 2014 bb <bb> 1.6.22-1pclos2014
- update

